@@ -11,6 +11,7 @@ from slack_sdk import version
 from slack_sdk.errors import SlackRequestError
 from slack_sdk.models.attachments import Attachment
 from slack_sdk.models.blocks import Block
+from slack_sdk.models.metadata import Metadata
 
 
 def convert_bool_to_0_or_1(
@@ -180,11 +181,13 @@ def _build_req_args(
 
 
 def _parse_web_class_objects(kwargs) -> None:
-    def to_dict(obj: Union[Dict, Block, Attachment]):
+    def to_dict(obj: Union[Dict, Block, Attachment, Metadata]):
         if isinstance(obj, Block):
             return obj.to_dict()
         if isinstance(obj, Attachment):
             return obj.to_dict()
+        if isinstance(obj, Metadata):
+            return obj.to_dict()
         return obj
 
     blocks = kwargs.get("blocks", None)
@@ -197,6 +200,10 @@ def _parse_web_class_objects(kwargs) -> None:
         dict_attachments = [to_dict(a) for a in attachments]
         kwargs.update({"attachments": dict_attachments})
 
+    metadata = kwargs.get("metadata", None)
+    if metadata is not None and isinstance(metadata, Metadata):
+        kwargs.update({"metadata": to_dict(metadata)})
+
 
 def _update_call_participants(
     kwargs, users: Union[str, Sequence[Dict[str, str]]]
